Struct style::invalidation::media_queries::EffectiveMediaQueryResults
[−]
[src]
pub struct EffectiveMediaQueryResults { /* fields omitted */ }A struct that holds the result of a media query evaluation pass for the media queries that evaluated successfully.
Methods
impl EffectiveMediaQueryResults[src]
pub fn new() -> Self[src]
Trivially constructs an empty EffectiveMediaQueryResults.
pub fn clear(&mut self)[src]
Resets the results, using an empty key.
pub fn was_effective<T>(&self, item: &T) -> bool where
T: ToMediaListKey, [src]
T: ToMediaListKey,
Returns whether a given item was known to be effective when the results were cached.
pub fn saw_effective<T>(&mut self, item: &T) where
T: ToMediaListKey, [src]
T: ToMediaListKey,
Notices that an effective item has been seen, and caches it as matching.